@@ -301,7 +301,7 @@ class ClockedSchedule(BaseScheduleModel):
         ]
 
     def __str__(self):
-        return '{}'.format(make_aware(self.clocked_time))
+        return f'{make_aware(self.clocked_time)}'
 
     @property
     def schedule(self):
@@ -400,9 +400,10 @@ class CrontabSchedule(BaseScheduleModel):
         ]
 
     def __str__(self):
-        return '{0} {1} {2} {3} {4} (m/h/dM/MY/d) {5}'.format(
-            cronexp(self.minute), cronexp(self.hour), cronexp(self.day_of_month),
-            cronexp(self.month_of_year), cronexp(self.day_of_week), str(self.timezone)
+        return (
+            f'{cronexp(self.minute)} {cronexp(self.hour)} '
+            f'{cronexp(self.day_of_month)} {cronexp(self.month_of_year)} '
+            f'{cronexp(self.day_of_week)} (m/h/dM/MY/d) {self.timezone}'
         )
 
     @property
